.. Copyright (C) 2018 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`FreeRADIUS <https://freeradius.org/>`__ is a RADIUS (Remote Authentication
Dial-In User Service) server. It can be used to set up Authorization,
Authentication and Accounting (AAA) services on a wired or wireless network.

The ``debops.freeradius`` Ansible role can be used to install and configure
FreeRADIUS server on a Debian/Ubuntu hosts.
